@@ -82,6 +82,9 @@ def main(argv=sys.argv[1:]):
         '--exclude', default=[],
         nargs='*',
         help='Exclude C/C++ files from being checked.')
+    parser.add_argument(
+        '--output', type=str,
+        help='The --output option for cpplint')
     parser.add_argument(
         'paths',
         nargs='*',
@@ -102,6 +105,8 @@ def main(argv=sys.argv[1:]):
     argv = []
     # collect category based counts
     argv.append('--counting=detailed')
+    if args.output:
+        argv.append('--output=%s' % args.output)
     argv.append('--extensions=%s' % ','.join(extensions))
     argv.append('--headers=%s' % ','.join(headers))
     filters = [
